[nautilus-actions/file-manager-actions] NAUpdater class is renamed to FMAUpdater



commit 6c2abbfabed183a850adefee20e7513dafb1cd09
Author: Pierre Wieser <pwieser trychlos org>
Date:   Tue Sep 8 12:43:35 2015 +0200

    NAUpdater class is renamed to FMAUpdater

 src/core/Makefile.am                     |    4 +-
 src/core/fma-iio-provider.c              |    2 +-
 src/core/{na-updater.c => fma-updater.c} |  160 +++++++++++++++---------------
 src/core/fma-updater.h                   |   97 ++++++++++++++++++
 src/core/na-updater.h                    |   97 ------------------
 src/nact/base-gtk-utils.c                |    2 +-
 src/nact/nact-application.c              |   10 +-
 src/nact/nact-application.h              |    4 +-
 src/nact/nact-assistant-export.c         |    4 +-
 src/nact/nact-assistant-import.c         |    2 +-
 src/nact/nact-clipboard.c                |    2 +-
 src/nact/nact-export-ask.c               |    2 +-
 src/nact/nact-main-window-def.h          |    2 +-
 src/nact/nact-main-window.c              |   10 +-
 src/nact/nact-menu-edit.c                |   12 +-
 src/nact/nact-menu-file.c                |   12 +-
 src/nact/nact-menu.c                     |    4 +-
 src/nact/nact-menu.h                     |    4 +-
 src/nact/nact-preferences-editor.c       |    2 +-
 src/nact/nact-providers-list.c           |    6 +-
 src/nact/nact-schemes-list.c             |    4 +-
 src/nact/nact-sort-buttons.c             |    8 +-
 src/nact/nact-sort-buttons.h             |    4 +-
 src/nact/nact-tree-ieditable.c           |    6 +-
 src/nact/nact-tree-model-dnd.c           |   12 +-
 src/utils/nautilus-actions-new.c         |   12 +-
 26 files changed, 242 insertions(+), 242 deletions(-)
---
diff --git a/src/core/Makefile.am b/src/core/Makefile.am
index 95a22c8..70f7ade 100644
--- a/src/core/Makefile.am
+++ b/src/core/Makefile.am
@@ -120,8 +120,8 @@ libna_core_la_SOURCES = \
        fma-timeout.c                                                                           \
        fma-tokens.c                                                                                    \
        fma-tokens.h                                                                                    \
-       na-updater.c                                                                            \
-       na-updater.h                                                                            \
+       fma-updater.c                                                                           \
+       fma-updater.h                                                                           \
        $(BUILT_SOURCES)                                                                        \
        $(NULL)
 
diff --git a/src/core/fma-iio-provider.c b/src/core/fma-iio-provider.c
index 8e1be74..151a0ca 100644
--- a/src/core/fma-iio-provider.c
+++ b/src/core/fma-iio-provider.c
@@ -200,7 +200,7 @@ do_is_able_to_write( const FMAIIOProvider *instance )
  * to ask the user if he is willing to reload such a current list (and
  * this is the way &nact; has chosen to deal with this message).
  *
- * Note that application FMAPivot/NAUpdater pivot is typically the only
+ * Note that application FMAPivot/FMAUpdater pivot is typically the only
  * object connected to this signal. It acts so as a filtering proxy,
  * re-emitting its own 'items-changed' signal for a whole set of detected
  * underlying modifications.
diff --git a/src/core/na-updater.c b/src/core/fma-updater.c
similarity index 76%
rename from src/core/na-updater.c
rename to src/core/fma-updater.c
index a9d43a6..b7708a2 100644
--- a/src/core/na-updater.c
+++ b/src/core/fma-updater.c
@@ -37,17 +37,17 @@
 
 #include "fma-io-provider.h"
 #include "fma-settings.h"
-#include "na-updater.h"
+#include "fma-updater.h"
 
 /* private class data
  */
-struct _NAUpdaterClassPrivate {
+struct _FMAUpdaterClassPrivate {
        void *empty;                                            /* so that gcc -pedantic is happy */
 };
 
 /* private instance data
  */
-struct _NAUpdaterPrivate {
+struct _FMAUpdaterPrivate {
        gboolean dispose_has_run;
        gboolean are_preferences_locked;
        gboolean is_level_zero_writable;
@@ -56,17 +56,17 @@ struct _NAUpdaterPrivate {
 static FMAPivotClass *st_parent_class = NULL;
 
 static GType    register_type( void );
-static void     class_init( NAUpdaterClass *klass );
+static void     class_init( FMAUpdaterClass *klass );
 static void     instance_init( GTypeInstance *instance, gpointer klass );
 static void     instance_dispose( GObject *object );
 static void     instance_finalize( GObject *object );
 
-static gboolean are_preferences_locked( const NAUpdater *updater );
-static gboolean is_level_zero_writable( const NAUpdater *updater );
-static void     set_writability_status( FMAObjectItem *item, const NAUpdater *updater );
+static gboolean are_preferences_locked( const FMAUpdater *updater );
+static gboolean is_level_zero_writable( const FMAUpdater *updater );
+static void     set_writability_status( FMAObjectItem *item, const FMAUpdater *updater );
 
 GType
-na_updater_get_type( void )
+fma_updater_get_type( void )
 {
        static GType object_type = 0;
 
@@ -80,32 +80,32 @@ na_updater_get_type( void )
 static GType
 register_type( void )
 {
-       static const gchar *thisfn = "na_updater_register_type";
+       static const gchar *thisfn = "fma_updater_register_type";
        GType type;
 
        static GTypeInfo info = {
-               sizeof( NAUpdaterClass ),
+               sizeof( FMAUpdaterClass ),
                ( GBaseInitFunc ) NULL,
                ( GBaseFinalizeFunc ) NULL,
                ( GClassInitFunc ) class_init,
                NULL,
                NULL,
-               sizeof( NAUpdater ),
+               sizeof( FMAUpdater ),
                0,
                ( GInstanceInitFunc ) instance_init
        };
 
        g_debug( "%s", thisfn );
 
-       type = g_type_register_static( FMA_TYPE_PIVOT, "NAUpdater", &info, 0 );
+       type = g_type_register_static( FMA_TYPE_PIVOT, "FMAUpdater", &info, 0 );
 
        return( type );
 }
 
 static void
-class_init( NAUpdaterClass *klass )
+class_init( FMAUpdaterClass *klass )
 {
-       static const gchar *thisfn = "na_updater_class_init";
+       static const gchar *thisfn = "fma_updater_class_init";
        GObjectClass *object_class;
 
        g_debug( "%s: klass=%p", thisfn, ( void * ) klass );
@@ -116,23 +116,23 @@ class_init( NAUpdaterClass *klass )
        object_class->dispose = instance_dispose;
        object_class->finalize = instance_finalize;
 
-       klass->private = g_new0( NAUpdaterClassPrivate, 1 );
+       klass->private = g_new0( FMAUpdaterClassPrivate, 1 );
 }
 
 static void
 instance_init( GTypeInstance *instance, gpointer klass )
 {
-       static const gchar *thisfn = "na_updater_instance_init";
-       NAUpdater *self;
+       static const gchar *thisfn = "fma_updater_instance_init";
+       FMAUpdater *self;
 
-       g_return_if_fail( NA_IS_UPDATER( instance ));
+       g_return_if_fail( FMA_IS_UPDATER( instance ));
 
        g_debug( "%s: instance=%p (%s), klass=%p",
                        thisfn, ( void * ) instance, G_OBJECT_TYPE_NAME( instance ), ( void * ) klass );
 
-       self = NA_UPDATER( instance );
+       self = FMA_UPDATER( instance );
 
-       self->private = g_new0( NAUpdaterPrivate, 1 );
+       self->private = g_new0( FMAUpdaterPrivate, 1 );
 
        self->private->dispose_has_run = FALSE;
 }
@@ -140,12 +140,12 @@ instance_init( GTypeInstance *instance, gpointer klass )
 static void
 instance_dispose( GObject *object )
 {
-       static const gchar *thisfn = "na_updater_instance_dispose";
-       NAUpdater *self;
+       static const gchar *thisfn = "fma_updater_instance_dispose";
+       FMAUpdater *self;
 
-       g_return_if_fail( NA_IS_UPDATER( object ));
+       g_return_if_fail( FMA_IS_UPDATER( object ));
 
-       self = NA_UPDATER( object );
+       self = FMA_UPDATER( object );
 
        if( !self->private->dispose_has_run ){
 
@@ -163,14 +163,14 @@ instance_dispose( GObject *object )
 static void
 instance_finalize( GObject *object )
 {
-       static const gchar *thisfn = "na_updater_instance_finalize";
-       NAUpdater *self;
+       static const gchar *thisfn = "fma_updater_instance_finalize";
+       FMAUpdater *self;
 
-       g_return_if_fail( NA_IS_UPDATER( object ));
+       g_return_if_fail( FMA_IS_UPDATER( object ));
 
        g_debug( "%s: object=%p (%s)", thisfn, ( void * ) object, G_OBJECT_TYPE_NAME( object ));
 
-       self = NA_UPDATER( object );
+       self = FMA_UPDATER( object );
 
        g_free( self->private );
 
@@ -181,19 +181,19 @@ instance_finalize( GObject *object )
 }
 
 /*
- * na_updater_new:
+ * fma_updater_new:
  *
- * Returns: a newly allocated #NAUpdater object.
+ * Returns: a newly allocated #FMAUpdater object.
  */
-NAUpdater *
-na_updater_new( void )
+FMAUpdater *
+fma_updater_new( void )
 {
-       static const gchar *thisfn = "na_updater_new";
-       NAUpdater *updater;
+       static const gchar *thisfn = "fma_updater_new";
+       FMAUpdater *updater;
 
        g_debug( "%s", thisfn );
 
-       updater = g_object_new( NA_TYPE_UPDATER, NULL );
+       updater = g_object_new( FMA_TYPE_UPDATER, NULL );
 
        updater->private->are_preferences_locked = are_preferences_locked( updater );
        updater->private->is_level_zero_writable = is_level_zero_writable( updater );
@@ -206,7 +206,7 @@ na_updater_new( void )
 }
 
 static gboolean
-are_preferences_locked( const NAUpdater *updater )
+are_preferences_locked( const FMAUpdater *updater )
 {
        gboolean are_locked;
        gboolean mandatory;
@@ -217,7 +217,7 @@ are_preferences_locked( const NAUpdater *updater )
 }
 
 static gboolean
-is_level_zero_writable( const NAUpdater *updater )
+is_level_zero_writable( const FMAUpdater *updater )
 {
        GSList *level_zero;
        gboolean mandatory;
@@ -226,15 +226,15 @@ is_level_zero_writable( const NAUpdater *updater )
 
        fma_core_utils_slist_free( level_zero );
 
-       g_debug( "na_updater_is_level_zero_writable: IPREFS_ITEMS_LEVEL_ZERO_ORDER: mandatory=%s",
+       g_debug( "fma_updater_is_level_zero_writable: IPREFS_ITEMS_LEVEL_ZERO_ORDER: mandatory=%s",
                        mandatory ? "True":"False" );
 
        return( !mandatory );
 }
 
 /*
- * na_updater_check_item_writability_status:
- * @updater: this #NAUpdater object.
+ * fma_updater_check_item_writability_status:
+ * @updater: this #FMAUpdater object.
  * @item: the #FMAObjectItem to be written.
  *
  * Compute and set the writability status of the @item.
@@ -248,14 +248,14 @@ is_level_zero_writable( const NAUpdater *updater )
  * If the item does not have a parent, then the level zero must be writable.
  */
 void
-na_updater_check_item_writability_status( const NAUpdater *updater, const FMAObjectItem *item )
+fma_updater_check_item_writability_status( const FMAUpdater *updater, const FMAObjectItem *item )
 {
        gboolean writable;
        FMAIOProvider *provider;
        FMAObjectItem *parent;
        guint reason;
 
-       g_return_if_fail( NA_IS_UPDATER( updater ));
+       g_return_if_fail( FMA_IS_UPDATER( updater ));
        g_return_if_fail( FMA_IS_OBJECT_ITEM( item ));
 
        writable = FALSE;
@@ -312,18 +312,18 @@ na_updater_check_item_writability_status( const NAUpdater *updater, const FMAObj
 }
 
 /*
- * na_updater_are_preferences_locked:
- * @updater: the #NAUpdater application object.
+ * fma_updater_are_preferences_locked:
+ * @updater: the #FMAUpdater application object.
  *
  * Returns: %TRUE if preferences have been globally locked down by an
  * admin, %FALSE else.
  */
 gboolean
-na_updater_are_preferences_locked( const NAUpdater *updater )
+fma_updater_are_preferences_locked( const FMAUpdater *updater )
 {
        gboolean are_locked;
 
-       g_return_val_if_fail( NA_IS_UPDATER( updater ), TRUE );
+       g_return_val_if_fail( FMA_IS_UPDATER( updater ), TRUE );
 
        are_locked = TRUE;
 
@@ -336,8 +336,8 @@ na_updater_are_preferences_locked( const NAUpdater *updater )
 }
 
 /*
- * na_updater_is_level_zero_writable:
- * @updater: the #NAUpdater application object.
+ * fma_updater_is_level_zero_writable:
+ * @updater: the #FMAUpdater application object.
  *
  * As of 3.1.0, level-zero is written as a user preference.
  *
@@ -355,11 +355,11 @@ na_updater_are_preferences_locked( const NAUpdater *updater )
  * %FALSE else.
  */
 gboolean
-na_updater_is_level_zero_writable( const NAUpdater *updater )
+fma_updater_is_level_zero_writable( const FMAUpdater *updater )
 {
        gboolean is_writable;
 
-       g_return_val_if_fail( NA_IS_UPDATER( updater ), FALSE );
+       g_return_val_if_fail( FMA_IS_UPDATER( updater ), FALSE );
 
        is_writable = FALSE;
 
@@ -372,18 +372,18 @@ na_updater_is_level_zero_writable( const NAUpdater *updater )
 }
 
 /*
- * na_updater_append_item:
- * @updater: this #NAUpdater object.
+ * fma_updater_append_item:
+ * @updater: this #FMAUpdater object.
  * @item: a #FMAObjectItem-derived object to be appended to the tree.
  *
  * Append a new item at the end of the global tree.
  */
 void
-na_updater_append_item( NAUpdater *updater, FMAObjectItem *item )
+fma_updater_append_item( FMAUpdater *updater, FMAObjectItem *item )
 {
        GList *tree;
 
-       g_return_if_fail( NA_IS_UPDATER( updater ));
+       g_return_if_fail( FMA_IS_UPDATER( updater ));
        g_return_if_fail( FMA_IS_OBJECT_ITEM( item ));
 
        if( !updater->private->dispose_has_run ){
@@ -395,8 +395,8 @@ na_updater_append_item( NAUpdater *updater, FMAObjectItem *item )
 }
 
 /*
- * na_updater_insert_item:
- * @updater: this #NAUpdater object.
+ * fma_updater_insert_item:
+ * @updater: this #FMAUpdater object.
  * @item: a #FMAObjectItem-derived object to be inserted in the tree.
  * @parent_id: the id of the parent, or %NULL.
  * @pos: the position in the children of the parent, starting at zero, or -1.
@@ -404,12 +404,12 @@ na_updater_append_item( NAUpdater *updater, FMAObjectItem *item )
  * Insert a new item in the global tree.
  */
 void
-na_updater_insert_item( NAUpdater *updater, FMAObjectItem *item, const gchar *parent_id, gint pos )
+fma_updater_insert_item( FMAUpdater *updater, FMAObjectItem *item, const gchar *parent_id, gint pos )
 {
        GList *tree;
        FMAObjectItem *parent;
 
-       g_return_if_fail( NA_IS_UPDATER( updater ));
+       g_return_if_fail( FMA_IS_UPDATER( updater ));
        g_return_if_fail( FMA_IS_OBJECT_ITEM( item ));
 
        if( !updater->private->dispose_has_run ){
@@ -432,14 +432,14 @@ na_updater_insert_item( NAUpdater *updater, FMAObjectItem *item, const gchar *pa
 }
 
 /*
- * na_updater_remove_item:
+ * fma_updater_remove_item:
  * @updater: this #FMAPivot instance.
  * @item: the #FMAObjectItem to be removed from the list.
  *
  * Removes a #FMAObjectItem from the hierarchical tree. Does not delete it.
  */
 void
-na_updater_remove_item( NAUpdater *updater, FMAObject *item )
+fma_updater_remove_item( FMAUpdater *updater, FMAObject *item )
 {
        GList *tree;
        FMAObjectItem *parent;
@@ -448,7 +448,7 @@ na_updater_remove_item( NAUpdater *updater, FMAObject *item )
 
        if( !updater->private->dispose_has_run ){
 
-               g_debug( "na_updater_remove_item: updater=%p, item=%p (%s)",
+               g_debug( "fma_updater_remove_item: updater=%p, item=%p (%s)",
                                ( void * ) updater,
                                ( void * ) item, G_IS_OBJECT( item ) ? G_OBJECT_TYPE_NAME( item ) : "(null)" 
);
 
@@ -467,8 +467,8 @@ na_updater_remove_item( NAUpdater *updater, FMAObject *item )
 }
 
 /**
- * na_updater_should_pasted_be_relabeled:
- * @updater: this #NAUpdater instance.
+ * fma_updater_should_pasted_be_relabeled:
+ * @updater: this #FMAUpdater instance.
  * @object: the considered #FMAObject-derived object.
  *
  * Whether the specified object should be relabeled when pasted ?
@@ -476,9 +476,9 @@ na_updater_remove_item( NAUpdater *updater, FMAObject *item )
  * Returns: %TRUE if the object should be relabeled, %FALSE else.
  */
 gboolean
-na_updater_should_pasted_be_relabeled( const NAUpdater *updater, const FMAObject *item )
+fma_updater_should_pasted_be_relabeled( const FMAUpdater *updater, const FMAObject *item )
 {
-       static const gchar *thisfn = "na_updater_should_pasted_be_relabeled";
+       static const gchar *thisfn = "fma_updater_should_pasted_be_relabeled";
        gboolean relabel;
 
        if( FMA_IS_OBJECT_MENU( item )){
@@ -499,8 +499,8 @@ na_updater_should_pasted_be_relabeled( const NAUpdater *updater, const FMAObject
 }
 
 /*
- * na_updater_load_items:
- * @updater: this #NAUpdater instance.
+ * fma_updater_load_items:
+ * @updater: this #FMAUpdater instance.
  *
  * Loads the items, updating simultaneously their writability status.
  *
@@ -509,12 +509,12 @@ na_updater_should_pasted_be_relabeled( const NAUpdater *updater, const FMAObject
  * Since: 3.1
  */
 GList *
-na_updater_load_items( NAUpdater *updater )
+fma_updater_load_items( FMAUpdater *updater )
 {
-       static const gchar *thisfn = "na_updater_load_items";
+       static const gchar *thisfn = "fma_updater_load_items";
        GList *tree;
 
-       g_return_val_if_fail( NA_IS_UPDATER( updater ), NULL );
+       g_return_val_if_fail( FMA_IS_UPDATER( updater ), NULL );
 
        tree = NULL;
 
@@ -530,11 +530,11 @@ na_updater_load_items( NAUpdater *updater )
 }
 
 static void
-set_writability_status( FMAObjectItem *item, const NAUpdater *updater )
+set_writability_status( FMAObjectItem *item, const FMAUpdater *updater )
 {
        GList *children;
 
-       na_updater_check_item_writability_status( updater, item );
+       fma_updater_check_item_writability_status( updater, item );
 
        if( FMA_IS_OBJECT_MENU( item )){
                children = fma_object_get_items( item );
@@ -543,8 +543,8 @@ set_writability_status( FMAObjectItem *item, const NAUpdater *updater )
 }
 
 /*
- * na_updater_write_item:
- * @updater: this #NAUpdater instance.
+ * fma_updater_write_item:
+ * @updater: this #FMAUpdater instance.
  * @item: a #FMAObjectItem to be written down to the storage subsystem.
  * @messages: the I/O provider can allocate and store here its error
  * messages.
@@ -554,13 +554,13 @@ set_writability_status( FMAObjectItem *item, const NAUpdater *updater )
  * Returns: the #FMAIIOProvider return code.
  */
 guint
-na_updater_write_item( const NAUpdater *updater, FMAObjectItem *item, GSList **messages )
+fma_updater_write_item( const FMAUpdater *updater, FMAObjectItem *item, GSList **messages )
 {
        guint ret;
 
        ret = FMA_IIO_PROVIDER_CODE_PROGRAM_ERROR;
 
-       g_return_val_if_fail( NA_IS_UPDATER( updater ), ret );
+       g_return_val_if_fail( FMA_IS_UPDATER( updater ), ret );
        g_return_val_if_fail( FMA_IS_OBJECT_ITEM( item ), ret );
        g_return_val_if_fail( messages, ret );
 
@@ -582,8 +582,8 @@ na_updater_write_item( const NAUpdater *updater, FMAObjectItem *item, GSList **m
 }
 
 /*
- * na_updater_delete_item:
- * @updater: this #NAUpdater instance.
+ * fma_updater_delete_item:
+ * @updater: this #FMAUpdater instance.
  * @item: the #FMAObjectItem to be deleted from the storage subsystem.
  * @messages: the I/O provider can allocate and store here its error
  * messages.
@@ -596,12 +596,12 @@ na_updater_write_item( const NAUpdater *updater, FMAObjectItem *item, GSList **m
  * doesn't have any attached provider. We so do nothing and return OK...
  */
 guint
-na_updater_delete_item( const NAUpdater *updater, const FMAObjectItem *item, GSList **messages )
+fma_updater_delete_item( const FMAUpdater *updater, const FMAObjectItem *item, GSList **messages )
 {
        guint ret;
        FMAIOProvider *provider;
 
-       g_return_val_if_fail( NA_IS_UPDATER( updater ), FMA_IIO_PROVIDER_CODE_PROGRAM_ERROR );
+       g_return_val_if_fail( FMA_IS_UPDATER( updater ), FMA_IIO_PROVIDER_CODE_PROGRAM_ERROR );
        g_return_val_if_fail( FMA_IS_OBJECT_ITEM( item ), FMA_IIO_PROVIDER_CODE_PROGRAM_ERROR );
        g_return_val_if_fail( messages, FMA_IIO_PROVIDER_CODE_PROGRAM_ERROR );
 
diff --git a/src/core/fma-updater.h b/src/core/fma-updater.h
new file mode 100644
index 0000000..5ac9f72
--- /dev/null
+++ b/src/core/fma-updater.h
@@ -0,0 +1,97 @@
+/*
+ * FileManager-Actions
+ * A file-manager extension which offers configurable context menu pivots.
+ *
+ * Copyright (C) 2005 The GNOME Foundation
+ * Copyright (C) 2006-2008 Frederic Ruaudel and others (see AUTHORS)
+ * Copyright (C) 2009-2015 Pierre Wieser and others (see AUTHORS)
+ *
+ * FileManager-Actions is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
+ * published by the Free Software Foundation; either version 2 of
+ * the License, or (at your option) any later version.
+ *
+ * FileManager-Actions is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+ * General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with FileManager-Actions; see the file COPYING. If not, see
+ * <http://www.gnu.org/licenses/>.
+ *
+ * Authors:
+ *   Frederic Ruaudel <grumz grumz net>
+ *   Rodrigo Moya <rodrigo gnome-db org>
+ *   Pierre Wieser <pwieser trychlos org>
+ *   ... and many others (see AUTHORS)
+ */
+
+#ifndef __CORE_FMA_UPDATER_H__
+#define __CORE_FMA_UPDATER_H__
+
+/* @title: FMAUpdater
+ * @short_description: The #FMAUpdater Class Definition
+ * @include: core/fma-updater.h
+ *
+ * #FMAUpdater is a #FMAPivot-derived class which allows its clients
+ * to update actions and menus.
+ */
+
+#include "fma-pivot.h"
+
+G_BEGIN_DECLS
+
+#define FMA_TYPE_UPDATER                ( fma_updater_get_type())
+#define FMA_UPDATER( object )           ( G_TYPE_CHECK_INSTANCE_CAST( object, FMA_TYPE_UPDATER, FMAUpdater ))
+#define FMA_UPDATER_CLASS( klass )      ( G_TYPE_CHECK_CLASS_CAST( klass, FMA_TYPE_UPDATER, FMAUpdaterClass 
))
+#define FMA_IS_UPDATER( object )        ( G_TYPE_CHECK_INSTANCE_TYPE( object, FMA_TYPE_UPDATER ))
+#define FMA_IS_UPDATER_CLASS( klass )   ( G_TYPE_CHECK_CLASS_TYPE(( klass ), FMA_TYPE_UPDATER ))
+#define FMA_UPDATER_GET_CLASS( object ) ( G_TYPE_INSTANCE_GET_CLASS(( object ), FMA_TYPE_UPDATER, 
FMAUpdaterClass ))
+
+typedef struct _FMAUpdaterPrivate       FMAUpdaterPrivate;
+
+typedef struct {
+       /*< private >*/
+       FMAPivot           parent;
+       FMAUpdaterPrivate *private;
+}
+       FMAUpdater;
+
+typedef struct _FMAUpdaterClassPrivate  FMAUpdaterClassPrivate;
+
+typedef struct {
+       /*< private >*/
+       FMAPivotClass           parent;
+       FMAUpdaterClassPrivate *private;
+}
+       FMAUpdaterClass;
+
+GType       fma_updater_get_type( void );
+
+FMAUpdater *fma_updater_new( void );
+
+/* writability status
+ */
+void        fma_updater_check_item_writability_status( const FMAUpdater *updater, const FMAObjectItem *item 
);
+
+gboolean    fma_updater_are_preferences_locked       ( const FMAUpdater *updater );
+gboolean    fma_updater_is_level_zero_writable       ( const FMAUpdater *updater );
+
+/* update the tree in memory
+ */
+void        fma_updater_append_item( FMAUpdater *updater, FMAObjectItem *item );
+void        fma_updater_insert_item( FMAUpdater *updater, FMAObjectItem *item, const gchar *parent_id, gint 
pos );
+void        fma_updater_remove_item( FMAUpdater *updater, FMAObject *item );
+
+gboolean    fma_updater_should_pasted_be_relabeled( const FMAUpdater *updater, const FMAObject *item );
+
+/* read from / write to the physical storage subsystem
+ */
+GList      *fma_updater_load_items ( FMAUpdater *updater );
+guint       fma_updater_write_item ( const FMAUpdater *updater, FMAObjectItem *item, GSList **messages );
+guint       fma_updater_delete_item( const FMAUpdater *updater, const FMAObjectItem *item, GSList **messages 
);
+
+G_END_DECLS
+
+#endif /* __CORE_FMA_UPDATER_H__ */
diff --git a/src/nact/base-gtk-utils.c b/src/nact/base-gtk-utils.c
index 0a7a9fb..77abe73 100644
--- a/src/nact/base-gtk-utils.c
+++ b/src/nact/base-gtk-utils.c
@@ -35,7 +35,7 @@
 #include <string.h>
 
 #include "core/fma-gtk-utils.h"
-#include "core/na-updater.h"
+#include "core/fma-updater.h"
 
 #include "base-gtk-utils.h"
 
diff --git a/src/nact/nact-application.h b/src/nact/nact-application.h
index 3887236..10e7cf4 100644
--- a/src/nact/nact-application.h
+++ b/src/nact/nact-application.h
@@ -49,7 +49,7 @@
 
 #include <gtk/gtk.h>
 
-#include "core/na-updater.h"
+#include "core/fma-updater.h"
 
 G_BEGIN_DECLS
 
@@ -103,7 +103,7 @@ int              nact_application_run_with_args       ( NactApplication *applica
 
 gchar           *nact_application_get_application_name( const NactApplication *application );
 
-NAUpdater       *nact_application_get_updater         ( const NactApplication *application );
+FMAUpdater       *nact_application_get_updater         ( const NactApplication *application );
 
 gboolean         nact_application_is_willing_to_quit  ( const NactApplication *application );
 
diff --git a/src/nact/nact-assistant-export.c b/src/nact/nact-assistant-export.c
index 65b4c9b..b0d2c77 100644
--- a/src/nact/nact-assistant-export.c
+++ b/src/nact/nact-assistant-export.c
@@ -201,7 +201,7 @@ ioptions_list_get_formats( const FMAIOptionsList *instance, GtkWidget *container
 {
        NactAssistantExport *window;
        NactApplication *application;
-       NAUpdater *updater;
+       FMAUpdater *updater;
        GList *formats;
 
        g_return_val_if_fail( NACT_IS_ASSISTANT_EXPORT( instance ), NULL );
@@ -755,7 +755,7 @@ assistant_apply( BaseAssistant *wnd, GtkAssistant *assistant )
        GList *ia;
        ExportStruct *str;
        NactApplication *application;
-       NAUpdater *updater;
+       FMAUpdater *updater;
        gboolean first;
 
        g_return_if_fail( NACT_IS_ASSISTANT_EXPORT( wnd ));
diff --git a/src/nact/nact-assistant-import.c b/src/nact/nact-assistant-import.c
index 86b1dbf..bcf55b2 100644
--- a/src/nact/nact-assistant-import.c
+++ b/src/nact/nact-assistant-import.c
@@ -649,7 +649,7 @@ assistant_apply( BaseAssistant *wnd, GtkAssistant *assistant )
        GList *insertable_items, *overriden_items;
        FMAImporterResult *result;
        NactApplication *application;
-       NAUpdater *updater;
+       FMAUpdater *updater;
        NactTreeView *items_view;
 
        g_return_if_fail( NACT_IS_ASSISTANT_IMPORT( wnd ));
diff --git a/src/nact/nact-clipboard.c b/src/nact/nact-clipboard.c
index 56e25d2..63deceb 100644
--- a/src/nact/nact-clipboard.c
+++ b/src/nact/nact-clipboard.c
@@ -568,7 +568,7 @@ export_row_object( NactClipboard *clipboard, FMAObject *object, const gchar *des
        static const gchar *thisfn = "nact_clipboard_export_row_object";
        GList *subitems, *isub;
        NactApplication *application;
-       NAUpdater *updater;
+       FMAUpdater *updater;
        FMAObjectItem *item;
        gchar *item_label;
        gint index;
diff --git a/src/nact/nact-export-ask.c b/src/nact/nact-export-ask.c
index 66d1ac8..d88e2fc 100644
--- a/src/nact/nact-export-ask.c
+++ b/src/nact/nact-export-ask.c
@@ -157,7 +157,7 @@ ioptions_list_get_formats( const FMAIOptionsList *instance, GtkWidget *container
 {
        NactExportAsk *window;
        NactApplication *application;
-       NAUpdater *updater;
+       FMAUpdater *updater;
        GList *formats;
 
        g_return_val_if_fail( NACT_IS_EXPORT_ASK( instance ), NULL );
diff --git a/src/nact/nact-main-window-def.h b/src/nact/nact-main-window-def.h
index 1a3c8c3..d043e15 100644
--- a/src/nact/nact-main-window-def.h
+++ b/src/nact/nact-main-window-def.h
@@ -56,7 +56,7 @@
  *  +-> [NactApplication]
  *  |    on_startup()
  *  |      |
- *  |      +-> na_updater_new()
+ *  |      +-> fma_updater_new()
  *  |          nact_menu_app()
  *  |
  *  |    on_activate()
diff --git a/src/nact/nact-main-window.c b/src/nact/nact-main-window.c
index df595d9..1ad8cc4 100644
--- a/src/nact/nact-main-window.c
+++ b/src/nact/nact-main-window.c
@@ -65,7 +65,7 @@
 struct _NactMainWindowPrivate {
        gboolean         dispose_has_run;
 
-       NAUpdater       *updater;
+       FMAUpdater       *updater;
 
        /**
         * Current action or menu.
@@ -183,7 +183,7 @@ static void       setup_dialog_title( NactMainWindow *window );
 static void       setup_writability_status( NactMainWindow *window );
 
 /* items have changed */
-static void       on_pivot_items_changed( NAUpdater *updater, NactMainWindow *window );
+static void       on_pivot_items_changed( FMAUpdater *updater, NactMainWindow *window );
 static gboolean   confirm_for_giveup_from_pivot( const NactMainWindow *window );
 static gboolean   confirm_for_giveup_from_menu( const NactMainWindow *window );
 static void       load_or_reload_items( NactMainWindow *window );
@@ -1116,12 +1116,12 @@ setup_writability_status( NactMainWindow *window )
  * in the underlying storage subsystems
  */
 static void
-on_pivot_items_changed( NAUpdater *updater, NactMainWindow *window )
+on_pivot_items_changed( FMAUpdater *updater, NactMainWindow *window )
 {
        static const gchar *thisfn = "nact_main_window_on_pivot_items_changed";
        gboolean reload_ok;
 
-       g_return_if_fail( NA_IS_UPDATER( updater ));
+       g_return_if_fail( FMA_IS_UPDATER( updater ));
        g_return_if_fail( NACT_IS_MAIN_WINDOW( window ));
 
        if( !window->private->dispose_has_run ){
@@ -1208,7 +1208,7 @@ load_or_reload_items( NactMainWindow *window )
        g_debug( "%s: window=%p", thisfn, ( void * ) window );
 
        raz_selection_properties( window );
-       tree = na_updater_load_items( window->private->updater );
+       tree = fma_updater_load_items( window->private->updater );
        nact_tree_view_fill( window->private->items_view, tree );
 
        g_debug( "%s: end of tree view filling", thisfn );
diff --git a/src/nact/nact-menu-edit.c b/src/nact/nact-menu-edit.c
index a0f2a85..1764310 100644
--- a/src/nact/nact-menu-edit.c
+++ b/src/nact/nact-menu-edit.c
@@ -47,8 +47,8 @@
 #include "nact-tree-view.h"
 
 static GList  *prepare_for_paste( NactMainWindow *window, sMenuData *sdata );
-static GList  *get_deletables( NAUpdater *updater, GList *tree, GSList **not_deletable );
-static GSList *get_deletables_rec( NAUpdater *updater, GList *tree );
+static GList  *get_deletables( FMAUpdater *updater, GList *tree, GSList **not_deletable );
+static GSList *get_deletables_rec( FMAUpdater *updater, GList *tree );
 static gchar  *add_ndeletable_msg( const FMAObjectItem *item, gint reason );
 static void    update_clipboard_counters( NactMainWindow *window, sMenuData *sdata );
 
@@ -365,7 +365,7 @@ prepare_for_paste( NactMainWindow *window, sMenuData *sdata )
                        }
                }
 
-               relabel = na_updater_should_pasted_be_relabeled( sdata->updater, FMA_OBJECT( it->data ));
+               relabel = fma_updater_should_pasted_be_relabeled( sdata->updater, FMA_OBJECT( it->data ));
                fma_object_prepare_for_paste( it->data, relabel, renumber, action );
                fma_object_check_status( it->data );
        }
@@ -416,7 +416,7 @@ nact_menu_edit_duplicate( NactMainWindow *main_window )
                        action = FMA_OBJECT_ACTION( fma_object_get_parent( it->data ));
                }
 
-               relabel = na_updater_should_pasted_be_relabeled( sdata->updater, obj );
+               relabel = fma_updater_should_pasted_be_relabeled( sdata->updater, obj );
                fma_object_prepare_for_paste( obj, relabel, TRUE, action );
                fma_object_set_origin( obj, NULL );
                fma_object_check_status( obj );
@@ -482,7 +482,7 @@ nact_menu_edit_delete( NactMainWindow *main_window )
 }
 
 static GList *
-get_deletables( NAUpdater *updater, GList *selected, GSList **ndeletables )
+get_deletables( FMAUpdater *updater, GList *selected, GSList **ndeletables )
 {
        GList *to_delete;
        GList *it;
@@ -523,7 +523,7 @@ get_deletables( NAUpdater *updater, GList *selected, GSList **ndeletables )
 }
 
 static GSList *
-get_deletables_rec( NAUpdater *updater, GList *tree )
+get_deletables_rec( FMAUpdater *updater, GList *tree )
 {
        GSList *msgs;
        GList *it;
diff --git a/src/nact/nact-menu-file.c b/src/nact/nact-menu-file.c
index 46a4780..46a8746 100644
--- a/src/nact/nact-menu-file.c
+++ b/src/nact/nact-menu-file.c
@@ -56,7 +56,7 @@ static gchar *st_save_warning     = N_( "Some items may not have been saved" );
 static gchar *st_level_zero_write = N_( "Unable to rewrite the level-zero items list" );
 static gchar *st_delete_error     = N_( "Some items have not been deleted" );
 
-static gboolean save_item( NactMainWindow *window, NAUpdater *updater, FMAObjectItem *item, GSList 
**messages );
+static gboolean save_item( NactMainWindow *window, FMAUpdater *updater, FMAObjectItem *item, GSList 
**messages );
 static void     install_autosave( NactMainWindow *main_window );
 static void     on_autosave_prefs_changed( const gchar *group, const gchar *key, gconstpointer new_value, 
gpointer user_data );
 static void     on_autosave_prefs_timeout( NactMainWindow *main_window );
@@ -132,7 +132,7 @@ nact_menu_file_new_menu( NactMainWindow *main_window )
        sdata = nact_menu_get_data( main_window );
        menu = fma_object_menu_new_with_defaults();
        fma_object_check_status( menu );
-       na_updater_check_item_writability_status( sdata->updater, FMA_OBJECT_ITEM( menu ));
+       fma_updater_check_item_writability_status( sdata->updater, FMA_OBJECT_ITEM( menu ));
        items = g_list_prepend( NULL, menu );
        items_view = nact_main_window_get_items_view( main_window );
        nact_tree_ieditable_insert_items( NACT_TREE_IEDITABLE( items_view ), items, NULL );
@@ -156,7 +156,7 @@ nact_menu_file_new_action( NactMainWindow *main_window )
        sdata = nact_menu_get_data( main_window );
        action = fma_object_action_new_with_defaults();
        fma_object_check_status( action );
-       na_updater_check_item_writability_status( sdata->updater, FMA_OBJECT_ITEM( action ));
+       fma_updater_check_item_writability_status( sdata->updater, FMA_OBJECT_ITEM( action ));
        items = g_list_prepend( NULL, action );
        items_view = nact_main_window_get_items_view( main_window );
        nact_tree_ieditable_insert_items( NACT_TREE_IEDITABLE( items_view ), items, NULL );
@@ -319,7 +319,7 @@ nact_menu_file_save_items( NactMainWindow *window )
  * iterates here on each and every FMAObjectItem row stored in the tree
  */
 static gboolean
-save_item( NactMainWindow *window, NAUpdater *updater, FMAObjectItem *item, GSList **messages )
+save_item( NactMainWindow *window, FMAUpdater *updater, FMAObjectItem *item, GSList **messages )
 {
        static const gchar *thisfn = "nact_menu_file_save_item";
        gboolean ret;
@@ -330,7 +330,7 @@ save_item( NactMainWindow *window, NAUpdater *updater, FMAObjectItem *item, GSLi
        guint save_ret;
 
        g_return_val_if_fail( NACT_IS_MAIN_WINDOW( window ), FALSE );
-       g_return_val_if_fail( NA_IS_UPDATER( updater ), FALSE );
+       g_return_val_if_fail( FMA_IS_UPDATER( updater ), FALSE );
        g_return_val_if_fail( FMA_IS_OBJECT_ITEM( item ), FALSE );
 
        ret = TRUE;
@@ -349,7 +349,7 @@ save_item( NactMainWindow *window, NAUpdater *updater, FMAObjectItem *item, GSLi
                g_debug( "%s: saving %p (%s) '%s'", thisfn, ( void * ) item, G_OBJECT_TYPE_NAME( item ), 
label );
                g_free( label );
 
-               save_ret = na_updater_write_item( updater, item, messages );
+               save_ret = fma_updater_write_item( updater, item, messages );
                ret = ( save_ret == FMA_IIO_PROVIDER_CODE_OK );
 
                if( ret ){
diff --git a/src/nact/nact-menu.c b/src/nact/nact-menu.c
index 71f51e8..0edec67 100644
--- a/src/nact/nact-menu.c
+++ b/src/nact/nact-menu.c
@@ -324,11 +324,11 @@ nact_menu_win( NactMainWindow *main_window )
        application = gtk_window_get_application( GTK_WINDOW( main_window ));
        g_return_if_fail( application && NACT_IS_APPLICATION( application ));
        sdata->updater = nact_application_get_updater( NACT_APPLICATION( application ));
-       sdata->is_level_zero_writable = na_updater_is_level_zero_writable( sdata->updater );
+       sdata->is_level_zero_writable = fma_updater_is_level_zero_writable( sdata->updater );
        sdata->has_writable_providers =
                        ( fma_io_provider_find_writable_io_provider( FMA_PIVOT( sdata->updater )) != NULL );
 
-       g_debug( "%s: na_updater_is_level_zero_writable=%s, fma_io_provider_find_writable_io_provider=%s",
+       g_debug( "%s: fma_updater_is_level_zero_writable=%s, fma_io_provider_find_writable_io_provider=%s",
                        thisfn,
                        sdata->is_level_zero_writable ? "True":"False",
                        sdata->has_writable_providers ? "True":"False" );
diff --git a/src/nact/nact-menu.h b/src/nact/nact-menu.h
index de37c5b..ff6f5e4 100644
--- a/src/nact/nact-menu.h
+++ b/src/nact/nact-menu.h
@@ -37,7 +37,7 @@
  * @include: nact-menu.h
  */
 
-#include "core/na-updater.h"
+#include "core/fma-updater.h"
 
 #include "nact-application.h"
 #include "nact-main-window-def.h"
@@ -52,7 +52,7 @@ typedef struct {
        /* set at initialization time
         */
        gulong          update_sensitivities_handler_id;
-       NAUpdater  *updater;
+       FMAUpdater  *updater;
        GMenuModel *maintainer;
        GMenuModel *popup;
        gboolean    is_level_zero_writable;
diff --git a/src/nact/nact-preferences-editor.c b/src/nact/nact-preferences-editor.c
index 5817f86..82a4580 100644
--- a/src/nact/nact-preferences-editor.c
+++ b/src/nact/nact-preferences-editor.c
@@ -259,7 +259,7 @@ ioptions_list_get_options( const FMAIOptionsList *instance, GtkWidget *container
        static const gchar *thisfn = "nact_preferences_editor_ioptions_list_get_options";
        GList *options;
        NactApplication *application;
-       NAUpdater *updater;
+       FMAUpdater *updater;
 
        g_return_val_if_fail( NACT_IS_PREFERENCES_EDITOR( instance ), NULL );
 
diff --git a/src/nact/nact-providers-list.c b/src/nact/nact-providers-list.c
index 3155264..a312c13 100644
--- a/src/nact/nact-providers-list.c
+++ b/src/nact/nact-providers-list.c
@@ -199,7 +199,7 @@ nact_providers_list_init_view( BaseWindow *window, GtkTreeView *treeview )
        static const gchar *thisfn = "nact_providers_list_init_view";
        ProvidersListData *data;
        NactApplication *application;
-       NAUpdater *updater;
+       FMAUpdater *updater;
 
        g_return_if_fail( BASE_IS_WINDOW( window ));
        g_return_if_fail( GTK_IS_TREE_VIEW( treeview ));
@@ -212,7 +212,7 @@ nact_providers_list_init_view( BaseWindow *window, GtkTreeView *treeview )
        data->window = window;
        application = NACT_APPLICATION( base_window_get_application( window ));
        updater = nact_application_get_updater( application );
-       data->preferences_locked = na_updater_are_preferences_locked( updater );
+       data->preferences_locked = fma_updater_are_preferences_locked( updater );
 
        init_view_setup_providers( treeview, window );
        init_view_connect_signals( treeview, window );
@@ -225,7 +225,7 @@ init_view_setup_providers( GtkTreeView *treeview, BaseWindow *window )
 {
        static const gchar *thisfn = "nact_providers_list_init_view_setup_providers";
        NactApplication *application;
-       NAUpdater *updater;
+       FMAUpdater *updater;
        GtkListStore *model;
        const GList *providers;
        const GList *iter;
diff --git a/src/nact/nact-schemes-list.c b/src/nact/nact-schemes-list.c
index d862628..135f19f 100644
--- a/src/nact/nact-schemes-list.c
+++ b/src/nact/nact-schemes-list.c
@@ -201,7 +201,7 @@ nact_schemes_list_init_view( GtkTreeView *treeview, BaseWindow *window, pf_new_s
        static const gchar *thisfn = "nact_schemes_list_init_view";
        SchemesListData *data;
        NactApplication *application;
-       NAUpdater *updater;
+       FMAUpdater *updater;
 
        g_debug( "%s: treeview=%p, window=%p",
                        thisfn,
@@ -217,7 +217,7 @@ nact_schemes_list_init_view( GtkTreeView *treeview, BaseWindow *window, pf_new_s
        data->window = window;
        application = NACT_APPLICATION( base_window_get_application( window ));
        updater = nact_application_get_updater( application );
-       data->preferences_locked = na_updater_are_preferences_locked( updater );
+       data->preferences_locked = fma_updater_are_preferences_locked( updater );
        data->editable = ( data->mode == SCHEMES_LIST_FOR_PREFERENCES && !data->preferences_locked );
        data->pf_on_sel_changed = pf;
        data->user_data = user_data;
diff --git a/src/nact/nact-sort-buttons.c b/src/nact/nact-sort-buttons.c
index cb0ad39..ddda1e0 100644
--- a/src/nact/nact-sort-buttons.c
+++ b/src/nact/nact-sort-buttons.c
@@ -33,7 +33,7 @@
 
 #include "core/fma-gtk-utils.h"
 #include "core/fma-iprefs.h"
-#include "core/na-updater.h"
+#include "core/fma-updater.h"
 
 #include "nact-application.h"
 #include "nact-main-window.h"
@@ -42,7 +42,7 @@
 
 struct _NactSortButtonsPrivate {
        gboolean        dispose_has_run;
-       NAUpdater      *updater;
+       FMAUpdater      *updater;
        gboolean        toggling;
        gint            active;
        guint           count_items;
@@ -371,8 +371,8 @@ enable_buttons( const NactSortButtons *sort_buttons, gboolean enabled )
        guint order_mode;
 
        priv = sort_buttons->private;
-       level_zero_writable = na_updater_is_level_zero_writable( priv->updater );
-       preferences_locked = na_updater_are_preferences_locked( priv->updater );
+       level_zero_writable = fma_updater_is_level_zero_writable( priv->updater );
+       preferences_locked = fma_updater_are_preferences_locked( priv->updater );
        finally_enabled = level_zero_writable && !preferences_locked && enabled;
 
        for( i=0 ; st_toggle_group[i].btn_name ; ++i ){
diff --git a/src/nact/nact-sort-buttons.h b/src/nact/nact-sort-buttons.h
index bee9bed..5b52e7b 100644
--- a/src/nact/nact-sort-buttons.h
+++ b/src/nact/nact-sort-buttons.h
@@ -43,8 +43,8 @@
  * Preferences editor).
  *
  * Modifying the sort order mode requires that:
- * - level zero is writable (see NAUpdater)
- * - preferences are not locked (see NAUpdater)
+ * - level zero is writable (see FMAUpdater)
+ * - preferences are not locked (see FMAUpdater)
  * - sort order mode is not a mandatory preference.
  */
 
diff --git a/src/nact/nact-tree-ieditable.c b/src/nact/nact-tree-ieditable.c
index 2715e22..5a97c4f 100644
--- a/src/nact/nact-tree-ieditable.c
+++ b/src/nact/nact-tree-ieditable.c
@@ -35,7 +35,7 @@
 #include <api/fma-object-api.h>
 
 #include <core/fma-factory-object.h>
-#include <core/na-updater.h>
+#include <core/fma-updater.h>
 
 #include "base-keysyms.h"
 #include "nact-application.h"
@@ -53,7 +53,7 @@ struct _NactTreeIEditableInterfacePrivate {
 /* data attached to the NactTreeView
  */
 typedef struct {
-       NAUpdater      *updater;
+       FMAUpdater      *updater;
        NactMainWindow *main_window;
        GtkTreeView    *treeview;
        NactTreeModel  *model;
@@ -584,7 +584,7 @@ nact_tree_ieditable_remove_deleted( NactTreeIEditable *instance, GSList **messag
                g_debug( "%s: item=%p (%s)", thisfn, ( void * ) item, G_OBJECT_TYPE_NAME( item ));
                fma_object_dump_norec( item );
 
-               if( na_updater_delete_item( ied->updater, item, messages ) != FMA_IIO_PROVIDER_CODE_OK ){
+               if( fma_updater_delete_item( ied->updater, item, messages ) != FMA_IIO_PROVIDER_CODE_OK ){
                        not_deleted = g_list_prepend( not_deleted, fma_object_ref( item ));
                        delete_ok = FALSE;
                }
diff --git a/src/nact/nact-tree-model-dnd.c b/src/nact/nact-tree-model-dnd.c
index 039bd70..a7fe5c2 100644
--- a/src/nact/nact-tree-model-dnd.c
+++ b/src/nact/nact-tree-model-dnd.c
@@ -564,7 +564,7 @@ drop_inside( NactTreeModel *model, GtkTreePath *dest, GtkSelectionData  *selecti
 {
        static const gchar *thisfn = "nact_tree_model_dnd_inside_drag_and_drop";
        NactApplication *application;
-       NAUpdater *updater;
+       FMAUpdater *updater;
        NactMainWindow *main_window;
        FMAObjectItem *parent;
        gboolean copy_data;
@@ -616,7 +616,7 @@ drop_inside( NactTreeModel *model, GtkTreePath *dest, GtkSelectionData  *selecti
                                        inserted = ( FMAObject * ) fma_object_duplicate( current, 
DUPLICATE_REC );
                                        fma_object_set_origin( inserted, NULL );
                                        fma_object_check_status( inserted );
-                                       relabel = na_updater_should_pasted_be_relabeled( updater, inserted );
+                                       relabel = fma_updater_should_pasted_be_relabeled( updater, inserted );
 
                                } else {
                                        inserted = fma_object_ref( current );
@@ -865,7 +865,7 @@ drop_uri_list( NactTreeModel *model, GtkTreePath *dest, GtkSelectionData  *selec
        NactTreeModelPrivate *priv;
        gboolean drop_done;
        GtkApplication *application;
-       NAUpdater *updater;
+       FMAUpdater *updater;
        NactMainWindow *main_window;
        FMAImporterParms parms;
        GList *import_results, *it;
@@ -927,7 +927,7 @@ drop_uri_list( NactTreeModel *model, GtkTreePath *dest, GtkSelectionData  *selec
                if( result->imported ){
                        if( !result->exist || result->mode == IMPORTER_MODE_RENUMBER ){
                                imported = g_list_prepend( imported, result->imported );
-                               na_updater_check_item_writability_status( updater, result->imported );
+                               fma_updater_check_item_writability_status( updater, result->imported );
 
                        } else if( result->mode == IMPORTER_MODE_OVERRIDE ){
                                overriden = g_list_prepend( overriden, result->imported );
@@ -1153,7 +1153,7 @@ static gboolean
 is_parent_accept_new_children( NactApplication *application, NactMainWindow *window, FMAObjectItem *parent )
 {
        gboolean accept_ok;
-       NAUpdater *updater;
+       FMAUpdater *updater;
        NactStatusbar *bar;
 
        accept_ok = FALSE;
@@ -1164,7 +1164,7 @@ is_parent_accept_new_children( NactApplication *application, NactMainWindow *win
         * ensure that level zero is writable
         */
        if( parent == NULL ){
-               if( na_updater_is_level_zero_writable( updater )){
+               if( fma_updater_is_level_zero_writable( updater )){
                        accept_ok = TRUE;
 
                } else {
diff --git a/src/utils/nautilus-actions-new.c b/src/utils/nautilus-actions-new.c
index e852b4b..4f3719d 100644
--- a/src/utils/nautilus-actions-new.c
+++ b/src/utils/nautilus-actions-new.c
@@ -45,7 +45,7 @@
 #include <core/fma-gconf-migration.h>
 #include <core/fma-io-provider.h>
 #include <core/fma-exporter.h>
-#include <core/na-updater.h>
+#include <core/fma-updater.h>
 
 #include "console-utils.h"
 
@@ -577,17 +577,17 @@ get_action_from_cmdline( void )
 static gboolean
 output_to_desktop( FMAObjectAction *action, GSList **msgs )
 {
-       NAUpdater *updater;
+       FMAUpdater *updater;
        FMAIOProvider *provider;
        guint ret;
        gboolean code;
 
-       updater = na_updater_new();
+       updater = fma_updater_new();
        provider = fma_io_provider_find_io_provider_by_id( FMA_PIVOT( updater ), "na-desktop" );
 
        if( provider ){
                fma_object_set_provider( action, provider );
-               ret = na_updater_write_item( updater, FMA_OBJECT_ITEM( action ), msgs );
+               ret = fma_updater_write_item( updater, FMA_OBJECT_ITEM( action ), msgs );
                code = ( ret == FMA_IIO_PROVIDER_CODE_OK );
 
        } else {
@@ -605,10 +605,10 @@ static gboolean
 output_to_stdout( const FMAObjectAction *action, GSList **msgs )
 {
        gboolean ret;
-       NAUpdater *updater;
+       FMAUpdater *updater;
        gchar *buffer;
 
-       updater = na_updater_new();
+       updater = fma_updater_new();
        buffer = fma_exporter_to_buffer( FMA_PIVOT( updater ), FMA_OBJECT_ITEM( action ), "Desktop1", msgs );
        ret = ( buffer != NULL );
 



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/src/nact/nact-application.c b/src/nact/nact-application.c
index 26de77d..5521b6b 100644
--- a/src/nact/nact-application.c
+++ b/src/nact/nact-application.c
@@ -55,7 +55,7 @@ struct _NactApplicationPrivate {
        GStrv           argv;
        int             code;
 
-       NAUpdater      *updater;
+       FMAUpdater      *updater;
 };
 
 static const gchar *st_application_name        = N_( "FileManager-Actions Configuration Tool" );
@@ -420,7 +420,7 @@ application_startup( GApplication *application )
        /* create the FMAPivot object (loading the plugins and so on)
         * after having dealt with command-line arguments
         */
-       priv->updater = na_updater_new();
+       priv->updater = fma_updater_new();
        fma_pivot_set_loadable( FMA_PIVOT( priv->updater ), PIVOT_LOAD_ALL );
 
        /* define the application menu */
@@ -538,16 +538,16 @@ nact_application_get_application_name( const NactApplication *application )
  * nact_application_get_updater:
  * @application: this NactApplication object.
  *
  * Returns a pointer on the #NAUpdater object.
  *
  * The returned pointer is owned by the #NactApplication object.
  * It should not be g_free() not g_object_unref() by the caller.
  */
-NAUpdater *
+FMAUpdater *
 nact_application_get_updater( const NactApplication *application )
 {
        NactApplicationPrivate *priv;
-       NAUpdater *updater = NULL;
+       FMAUpdater *updater = NULL;
 
        g_return_val_if_fail( application && NACT_IS_APPLICATION( application ), NULL );
 
@@ -538,16 +538,16 @@ nact_application_get_application_name( const NactApplication *application )
  * @application: this NactApplication object.
  *
- * Returns a pointer on the #NAUpdater object.
+ * Returns a pointer on the #FMAUpdater object.
  *
  * The returned pointer is owned by the #NactApplication object.